@@ -102,7 +102,13 @@ session_info = function(packages = NULL, dependencies = TRUE) {
     i = grep('^(attached base packages|Matrix products):\\s*$', res, ignore.case = TRUE)
     if (length(i)) res = res[-c(i, i + 1)]
     res = gsubi('^\\s*locale:\\s*$', 'Locale:', res)
+    res = gsub('^\\s*\\[[0-9]+]\\s*', '  ', res)  # remove vector indices like [1]
     res = gsubi('^\\s*other attached packages:\\s*$', 'Package version:', res)
+    # print the locale info on a single line if possible
+    if (length(i <- which(res == 'Locale:')) == 1 && res[i + 2] == '') {
+      res[i] = paste(res[i], gsub('\\s*/\\s*', ' / ', gsub('^\\s+', '', res[i + 1])))
+      res = res[-(i + 1)]
+    }
     raw_string(c(res, extra))
   }
 
@@ -135,3 +141,47 @@ session_info = function(packages = NULL, dependencies = TRUE) {
 }
 
 gsubi = function(...) gsub(..., ignore.case = TRUE)
+
+#' Try various methods to download a file
+#'
+#' Try all possible methods in \code{\link{download.file}()} (e.g.,
+#' \code{libcurl}, \code{curl}, \code{wget}, and \code{wininet}) and see if any
+#' method can succeed. The reason to enumerate all methods is that sometimes the
+#' default method does not work, e.g.,
+#' \url{https://stat.ethz.ch/pipermail/r-devel/2016-June/072852.html}.
+#' @param url The URL of the file.
+#' @param output Path to the output file. If not provided, the base name of the
+#'   URL will be used (query parameters and hash in the URL will be removed).
+#' @param ... Other arguments to be passed to \code{\link{download.file}()}
+#'   (except \code{method}).
+#' @return The integer code \code{0} for success, or an error if none of the
+#'   methods work.
+#' @export
+download_file = function(url, output = basename(url), ...) {
+  if (missing(output)) output = gsub('[?#].*$', '', output)  # remove query/hash
+  download = function(method = 'auto') download.file(url, output, ..., method = method)
+  if (is_windows()) for (method in c('libcurl', 'wininet', 'auto')) {
+    if (!inherits(try_silent(res <- download(method = method)), 'try-error') && res == 0)
+      return(res)
+  }
+
+  R340 = getRversion() >= '3.4.0'
+  if (R340 && download() == 0) return(0L)
+  # check for libcurl/curl/wget/lynx, call download.file with appropriate method
+  res = NA
+  if (Sys.which('curl') != '') {
+    # curl needs to add a -L option to follow redirects
+    opts = if (is.null(getOption('download.file.extra'))) options(download.file.extra = '-L')
+    res = download(method = 'curl'); options(opts)
+    if (res == 0) return(res)
+  }
+  if (Sys.which('wget') != '') {
+    if ((res <- download(method = 'wget')) == 0) return(res)
+  }
+  if (Sys.which('lynx') != '') {
+    if ((res <- download(method = 'lynx')) == 0) return(res)
+  }
+  if (is.na(res)) stop('No download method found (auto/wininet/wget/curl/lynx)')
+
+  res
+}
